@@ -7,6 +7,12 @@ import zigpy_znp.types as t
 from zigpy_znp.types import nvids
 
 
+class BootloaderBuildType(t.enum_uint8):
+    NON_BOOTLOADER_BUILD = 0
+    BUILT_AS_BIN = 1
+    BUILT_AS_HEX = 2
+
+
 class SYS(t.CommandsBase, subsystem=t.Subsystem.SYS):
     # reset the target device
     ResetReq = t.CommandDef(
@@ -60,6 +66,25 @@ class SYS(t.CommandsBase, subsystem=t.Subsystem.SYS):
                 t.Param("MajorRel", t.uint8_t, "Software major release number"),
                 t.Param("MinorRel", t.uint8_t, "Software minor release number"),
                 t.Param("MaintRel", t.uint8_t, "Software maintenance release number"),
+                # Optional stuff
+                t.Param(
+                    "CodeRevision",
+                    t.uint32_t,
+                    "User-supplied code revision number",
+                    optional=True,
+                ),
+                t.Param(
+                    "BootloaderBuildType",
+                    BootloaderBuildType,
+                    "Bootloader build type",
+                    optional=True,
+                ),
+                t.Param(
+                    "BootloaderRevision",
+                    t.uint32_t,
+                    "Bootloader revision. 0 - not provided, 0xFFFFFFFF - not supported",
+                    optional=True,
+                ),
             )
         ),
     )
